@@ -1,4 +1,4 @@
-import Py_FS.wrapper.nature_inspired
+import wrapper.nature_inspired
 
 __all__ = [
     "nature_inspired"
